@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-#
 # This file is part of django-ca (https://github.com/mathiasertl/django-ca).
 #
 # django-ca is free software: you can redistribute it and/or modify it under the terms of the GNU
@@ -14,8 +12,7 @@
 # see <http://www.gnu.org/licenses/>.
 
 from django.apps import AppConfig
-
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 
 class DjangoCAConfig(AppConfig):
