@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-#
 # This file is part of django-ca (https://github.com/mathiasertl/django-ca).
 #
 # django-ca is free software: you can redistribute it and/or modify it under the terms of the GNU
@@ -13,15 +11,22 @@
 # You should have received a copy of the GNU General Public License along with django-ca.  If not,
 # see <http://www.gnu.org/licenses/>.
 
-from django_ca.management.base import CertCommand
+from django.core.management.base import CommandError
+
+from ..base import CertCommand
+from ..base import ReasonAction
 
 
 class Command(CertCommand):
+    allow_revoked = True
     help = "Revoke a certificate."
 
     def add_arguments(self, parser):
-        parser.add_argument('--reason', help="An optional reason for revokation.")
+        parser.add_argument('--reason', action=ReasonAction, help="An optional reason for revokation.")
         super(Command, self).add_arguments(parser)
 
     def handle(self, cert, **options):
+        if cert.revoked:
+            raise CommandError('%s: Certificate is already revoked.' % cert.serial)
+
         cert.revoke(reason=options.get('reason'))
